package widgets
import "zgo.at/goatcounter/v2/widgets"
Index ¶
- Variables
- type Args
- type Browsers
- func (w Browsers) Err() error
- func (w *Browsers) GetData(ctx context.Context, a Args) (more bool, err error)
- func (w Browsers) HTML() template.HTML
- func (w Browsers) ID() int
- func (w Browsers) Label(ctx context.Context) string
- func (w Browsers) Name() string
- func (w Browsers) RenderHTML(ctx context.Context, shared SharedData) (string, any)
- func (w *Browsers) SetErr(h error)
- func (w *Browsers) SetHTML(h template.HTML)
- func (w *Browsers) SetSettings(s goatcounter.WidgetSettings)
- func (w Browsers) Settings() goatcounter.WidgetSettings
- func (w Browsers) Type() string
- type Campaigns
- func (w Campaigns) Err() error
- func (w *Campaigns) GetData(ctx context.Context, a Args) (more bool, err error)
- func (w Campaigns) HTML() template.HTML
- func (w Campaigns) ID() int
- func (w Campaigns) Label(ctx context.Context) string
- func (w Campaigns) Name() string
- func (w Campaigns) RenderHTML(ctx context.Context, shared SharedData) (string, any)
- func (w *Campaigns) SetErr(h error)
- func (w *Campaigns) SetHTML(h template.HTML)
- func (w *Campaigns) SetSettings(s goatcounter.WidgetSettings)
- func (w Campaigns) Settings() goatcounter.WidgetSettings
- func (w Campaigns) Type() string
- type Dummy
- func (w Dummy) Err() error
- func (w *Dummy) GetData(ctx context.Context, a Args) (more bool, err error)
- func (w Dummy) HTML() template.HTML
- func (w Dummy) ID() int
- func (w Dummy) Label(ctx context.Context) string
- func (w Dummy) Name() string
- func (w Dummy) RenderHTML(context.Context, SharedData) (string, any)
- func (w *Dummy) SetErr(h error)
- func (w *Dummy) SetHTML(h template.HTML)
- func (w *Dummy) SetSettings(s goatcounter.WidgetSettings)
- func (w Dummy) Settings() goatcounter.WidgetSettings
- func (w Dummy) Type() string
- type Languages
- func (w Languages) Err() error
- func (w *Languages) GetData(ctx context.Context, a Args) (more bool, err error)
- func (w Languages) HTML() template.HTML
- func (w Languages) ID() int
- func (w Languages) Label(ctx context.Context) string
- func (w Languages) Name() string
- func (w Languages) RenderHTML(ctx context.Context, shared SharedData) (string, any)
- func (w *Languages) SetErr(h error)
- func (w *Languages) SetHTML(h template.HTML)
- func (w *Languages) SetSettings(s goatcounter.WidgetSettings)
- func (w Languages) Settings() goatcounter.WidgetSettings
- func (w Languages) Type() string
- type List
- func FromSiteWidgets(ctx context.Context, www goatcounter.Widgets, params zint.Bitflag8) List
- func ListAllWidgets() List
- func (l List) Get(name string) List
- func (l List) GetOne(name string) Widget
- func (l List) InitialAndLazy() (initial List, lazy List)
- type Locations
- func (w Locations) Err() error
- func (w *Locations) GetData(ctx context.Context, a Args) (more bool, err error)
- func (w Locations) HTML() template.HTML
- func (w Locations) ID() int
- func (w Locations) Label(ctx context.Context) string
- func (w Locations) Name() string
- func (w Locations) RenderHTML(ctx context.Context, shared SharedData) (string, any)
- func (w *Locations) SetErr(h error)
- func (w *Locations) SetHTML(h template.HTML)
- func (w *Locations) SetSettings(s goatcounter.WidgetSettings)
- func (w Locations) Settings() goatcounter.WidgetSettings
- func (w Locations) Type() string
- type Pages
- func (w Pages) Err() error
- func (w *Pages) GetData(ctx context.Context, a Args) (bool, error)
- func (w Pages) HTML() template.HTML
- func (w Pages) ID() int
- func (w Pages) Label(ctx context.Context) string
- func (w Pages) Name() string
- func (w Pages) RenderHTML(ctx context.Context, shared SharedData) (string, any)
- func (w *Pages) SetErr(h error)
- func (w *Pages) SetHTML(h template.HTML)
- func (w *Pages) SetSettings(s goatcounter.WidgetSettings)
- func (w Pages) Settings() goatcounter.WidgetSettings
- func (w Pages) Type() string
- type SharedData
- type Sizes
- func (w Sizes) Err() error
- func (w *Sizes) GetData(ctx context.Context, a Args) (more bool, err error)
- func (w Sizes) HTML() template.HTML
- func (w Sizes) ID() int
- func (w Sizes) Label(ctx context.Context) string
- func (w Sizes) Name() string
- func (w Sizes) RenderHTML(ctx context.Context, shared SharedData) (string, any)
- func (w *Sizes) SetErr(h error)
- func (w *Sizes) SetHTML(h template.HTML)
- func (w *Sizes) SetSettings(s goatcounter.WidgetSettings)
- func (w Sizes) Settings() goatcounter.WidgetSettings
- func (w Sizes) Type() string
- type Systems
- func (w Systems) Err() error
- func (w *Systems) GetData(ctx context.Context, a Args) (more bool, err error)
- func (w Systems) HTML() template.HTML
- func (w Systems) ID() int
- func (w Systems) Label(ctx context.Context) string
- func (w Systems) Name() string
- func (w Systems) RenderHTML(ctx context.Context, shared SharedData) (string, any)
- func (w *Systems) SetErr(h error)
- func (w *Systems) SetHTML(h template.HTML)
- func (w *Systems) SetSettings(s goatcounter.WidgetSettings)
- func (w Systems) Settings() goatcounter.WidgetSettings
- func (w Systems) Type() string
- type TopRefs
- func (w TopRefs) Err() error
- func (w *TopRefs) GetData(ctx context.Context, a Args) (more bool, err error)
- func (w TopRefs) HTML() template.HTML
- func (w TopRefs) ID() int
- func (w TopRefs) Label(ctx context.Context) string
- func (w TopRefs) Name() string
- func (w TopRefs) RenderHTML(ctx context.Context, shared SharedData) (string, any)
- func (w *TopRefs) SetErr(h error)
- func (w *TopRefs) SetHTML(h template.HTML)
- func (w *TopRefs) SetSettings(s goatcounter.WidgetSettings)
- func (w TopRefs) Settings() goatcounter.WidgetSettings
- func (w TopRefs) Type() string
- type TotalCount
- func (w TotalCount) Err() error
- func (w *TotalCount) GetData(ctx context.Context, a Args) (more bool, err error)
- func (w TotalCount) HTML() template.HTML
- func (w TotalCount) ID() int
- func (w TotalCount) Label(ctx context.Context) string
- func (w TotalCount) Name() string
- func (w TotalCount) RenderHTML(context.Context, SharedData) (string, any)
- func (w *TotalCount) SetErr(h error)
- func (w *TotalCount) SetHTML(h template.HTML)
- func (w *TotalCount) SetSettings(s goatcounter.WidgetSettings)
- func (w TotalCount) Settings() goatcounter.WidgetSettings
- func (w TotalCount) Type() string
- type TotalPages
- func (w TotalPages) Err() error
- func (w *TotalPages) GetData(ctx context.Context, a Args) (more bool, err error)
- func (w TotalPages) HTML() template.HTML
- func (w TotalPages) ID() int
- func (w TotalPages) Label(ctx context.Context) string
- func (w TotalPages) Name() string
- func (w TotalPages) RenderHTML(ctx context.Context, shared SharedData) (string, any)
- func (w *TotalPages) SetErr(h error)
- func (w *TotalPages) SetHTML(h template.HTML)
- func (w *TotalPages) SetSettings(s goatcounter.WidgetSettings)
- func (w TotalPages) Settings() goatcounter.WidgetSettings
- func (w TotalPages) Type() string
- type Widget
Variables ¶
Types ¶
type Args ¶
type Args struct {
Rng ztime.Range
Offset int
PathFilter []int64
Daily bool
ForcedDaily bool
ShowRefs int64
}
type Browsers ¶
type Browsers struct {
Limit int
Detail string
Stats goatcounter.HitStats
// contains filtered or unexported fields
}
func (Browsers) Err ¶
func (*Browsers) GetData ¶
func (Browsers) HTML ¶
func (Browsers) ID ¶
func (Browsers) Label ¶
func (Browsers) Name ¶
func (Browsers) RenderHTML ¶
func (*Browsers) SetErr ¶
func (*Browsers) SetHTML ¶
func (*Browsers) SetSettings ¶
func (w *Browsers) SetSettings(s goatcounter.WidgetSettings)
func (Browsers) Settings ¶
func (w Browsers) Settings() goatcounter.WidgetSettings
func (Browsers) Type ¶
type Campaigns ¶
type Campaigns struct {
Limit int
Campaign int64
Stats goatcounter.HitStats
// contains filtered or unexported fields
}
func (Campaigns) Err ¶
func (*Campaigns) GetData ¶
func (Campaigns) HTML ¶
func (Campaigns) ID ¶
func (Campaigns) Label ¶
func (Campaigns) Name ¶
func (Campaigns) RenderHTML ¶
func (*Campaigns) SetErr ¶
func (*Campaigns) SetHTML ¶
func (*Campaigns) SetSettings ¶
func (w *Campaigns) SetSettings(s goatcounter.WidgetSettings)
func (Campaigns) Settings ¶
func (w Campaigns) Settings() goatcounter.WidgetSettings
func (Campaigns) Type ¶
type Dummy ¶
type Dummy struct {
}
func (Dummy) Err ¶
func (*Dummy) GetData ¶
func (Dummy) HTML ¶
func (Dummy) ID ¶
func (Dummy) Label ¶
func (Dummy) Name ¶
func (Dummy) RenderHTML ¶
func (*Dummy) SetErr ¶
func (*Dummy) SetHTML ¶
func (*Dummy) SetSettings ¶
func (w *Dummy) SetSettings(s goatcounter.WidgetSettings)
func (Dummy) Settings ¶
func (w Dummy) Settings() goatcounter.WidgetSettings
func (Dummy) Type ¶
type Languages ¶
type Languages struct {
Limit int
Stats goatcounter.HitStats
// contains filtered or unexported fields
}
func (Languages) Err ¶
func (*Languages) GetData ¶
func (Languages) HTML ¶
func (Languages) ID ¶
func (Languages) Label ¶
func (Languages) Name ¶
func (Languages) RenderHTML ¶
func (*Languages) SetErr ¶
func (*Languages) SetHTML ¶
func (*Languages) SetSettings ¶
func (w *Languages) SetSettings(s goatcounter.WidgetSettings)
func (Languages) Settings ¶
func (w Languages) Settings() goatcounter.WidgetSettings
func (Languages) Type ¶
type List ¶
type List []Widget
func FromSiteWidgets ¶
func ListAllWidgets ¶
func ListAllWidgets() List
ListAllWidgets returns a static list of all widgets that this user can add.
func (List) Get ¶
Get all widgets from the list by name.
func (List) GetOne ¶
GetOne gets the first widget in the list by name.
You usually want to use Get()! Only intended to get "internal" widgets where you know it will always have exactly one in the list.
func (List) InitialAndLazy ¶
Initial gets all widgets that should be loaded on the initial pageview (all internal widgets + the first one).
type Locations ¶
type Locations struct {
Limit int
Detail string
Stats goatcounter.HitStats
// contains filtered or unexported fields
}
func (Locations) Err ¶
func (*Locations) GetData ¶
func (Locations) HTML ¶
func (Locations) ID ¶
func (Locations) Label ¶
func (Locations) Name ¶
func (Locations) RenderHTML ¶
func (*Locations) SetErr ¶
func (*Locations) SetHTML ¶
func (*Locations) SetSettings ¶
func (w *Locations) SetSettings(s goatcounter.WidgetSettings)
func (Locations) Settings ¶
func (w Locations) Settings() goatcounter.WidgetSettings
func (Locations) Type ¶
type Pages ¶
type Pages struct {
RefsForPath int64
Style string
Limit, LimitRefs int
Display int
More bool
Pages goatcounter.HitLists
Refs goatcounter.HitStats
Max int
Exclude []int64
Diff []float64
// contains filtered or unexported fields
}
func (Pages) Err ¶
func (*Pages) GetData ¶
func (Pages) HTML ¶
func (Pages) ID ¶
func (Pages) Label ¶
func (Pages) Name ¶
func (Pages) RenderHTML ¶
func (*Pages) SetErr ¶
func (*Pages) SetHTML ¶
func (*Pages) SetSettings ¶
func (w *Pages) SetSettings(s goatcounter.WidgetSettings)
func (Pages) Settings ¶
func (w Pages) Settings() goatcounter.WidgetSettings
func (Pages) Type ¶
type SharedData ¶
SharedData gets passed to every widget.
type Sizes ¶
type Sizes struct {
Limit int
Detail string
Stats goatcounter.HitStats
// contains filtered or unexported fields
}
func (Sizes) Err ¶
func (*Sizes) GetData ¶
func (Sizes) HTML ¶
func (Sizes) ID ¶
func (Sizes) Label ¶
func (Sizes) Name ¶
func (Sizes) RenderHTML ¶
func (*Sizes) SetErr ¶
func (*Sizes) SetHTML ¶
func (*Sizes) SetSettings ¶
func (w *Sizes) SetSettings(s goatcounter.WidgetSettings)
func (Sizes) Settings ¶
func (w Sizes) Settings() goatcounter.WidgetSettings
func (Sizes) Type ¶
type Systems ¶
type Systems struct {
Limit int
Detail string
Stats goatcounter.HitStats
// contains filtered or unexported fields
}
func (Systems) Err ¶
func (*Systems) GetData ¶
func (Systems) HTML ¶
func (Systems) ID ¶
func (Systems) Label ¶
func (Systems) Name ¶
func (Systems) RenderHTML ¶
func (*Systems) SetErr ¶
func (*Systems) SetHTML ¶
func (*Systems) SetSettings ¶
func (w *Systems) SetSettings(s goatcounter.WidgetSettings)
func (Systems) Settings ¶
func (w Systems) Settings() goatcounter.WidgetSettings
func (Systems) Type ¶
type TopRefs ¶
type TopRefs struct {
Limit int
Ref string
TopRefs goatcounter.HitStats
// contains filtered or unexported fields
}
func (TopRefs) Err ¶
func (*TopRefs) GetData ¶
func (TopRefs) HTML ¶
func (TopRefs) ID ¶
func (TopRefs) Label ¶
func (TopRefs) Name ¶
func (TopRefs) RenderHTML ¶
func (*TopRefs) SetErr ¶
func (*TopRefs) SetHTML ¶
func (*TopRefs) SetSettings ¶
func (w *TopRefs) SetSettings(s goatcounter.WidgetSettings)
func (TopRefs) Settings ¶
func (w TopRefs) Settings() goatcounter.WidgetSettings
func (TopRefs) Type ¶
type TotalCount ¶
type TotalCount struct {
goatcounter.TotalCount
NoEvents bool
// contains filtered or unexported fields
}
func (TotalCount) Err ¶
func (w TotalCount) Err() error
func (*TotalCount) GetData ¶
func (TotalCount) HTML ¶
func (w TotalCount) HTML() template.HTML
func (TotalCount) ID ¶
func (w TotalCount) ID() int
func (TotalCount) Label ¶
func (w TotalCount) Label(ctx context.Context) string
func (TotalCount) Name ¶
func (w TotalCount) Name() string
func (TotalCount) RenderHTML ¶
func (w TotalCount) RenderHTML(context.Context, SharedData) (string, any)
func (*TotalCount) SetErr ¶
func (w *TotalCount) SetErr(h error)
func (*TotalCount) SetHTML ¶
func (w *TotalCount) SetHTML(h template.HTML)
func (*TotalCount) SetSettings ¶
func (w *TotalCount) SetSettings(s goatcounter.WidgetSettings)
func (TotalCount) Settings ¶
func (w TotalCount) Settings() goatcounter.WidgetSettings
func (TotalCount) Type ¶
func (w TotalCount) Type() string
type TotalPages ¶
type TotalPages struct {
Align, NoEvents bool
Style string
Max int
Total goatcounter.HitList
// contains filtered or unexported fields
}
func (TotalPages) Err ¶
func (w TotalPages) Err() error
func (*TotalPages) GetData ¶
func (TotalPages) HTML ¶
func (w TotalPages) HTML() template.HTML
func (TotalPages) ID ¶
func (w TotalPages) ID() int
func (TotalPages) Label ¶
func (w TotalPages) Label(ctx context.Context) string
func (TotalPages) Name ¶
func (w TotalPages) Name() string
func (TotalPages) RenderHTML ¶
func (w TotalPages) RenderHTML(ctx context.Context, shared SharedData) (string, any)
func (*TotalPages) SetErr ¶
func (w *TotalPages) SetErr(h error)
func (*TotalPages) SetHTML ¶
func (w *TotalPages) SetHTML(h template.HTML)
func (*TotalPages) SetSettings ¶
func (w *TotalPages) SetSettings(s goatcounter.WidgetSettings)
func (TotalPages) Settings ¶
func (w TotalPages) Settings() goatcounter.WidgetSettings
func (TotalPages) Type ¶
func (w TotalPages) Type() string
type Widget ¶
type Widget interface {
GetData(context.Context, Args) (bool, error)
RenderHTML(context.Context, SharedData) (string, any)
SetHTML(template.HTML)
HTML() template.HTML
SetErr(error)
Err() error
SetSettings(goatcounter.WidgetSettings)
Settings() goatcounter.WidgetSettings
ID() int
Name() string
Type() string // "full-width", "hchart"
Label(context.Context) string
}
func FromSiteWidget ¶
func NewWidget ¶
Source Files ¶
browsers.go campaigns.go dummy.go internal.go languages.go locations.go pages.go sizes.go systems.go toprefs.go total_pages.go widgets.go
- Version
- v2.5.0 (latest)
- Published
- Dec 14, 2023
- Platform
- linux/amd64
- Imports
- 10 packages
- Last checked
- 8 months ago –
Tools for package owners.